check_cuts_array
===================================================================

.. currentmodule:: skchange.utils.validation.cuts

.. autofunction:: check_cuts_array

.. include:: skchange.utils.validation.cuts.check_cuts_array.examples

.. raw:: html

    <div class="clearer"></div>